@@ -7,8 +7,10 @@
 #
 
 import struct
+import tarfile
 import numpy as np
 from itertools import repeat
+from ._error import NotHaveSetArgError
 
 
 def _set_table(section5):
@@ -30,7 +32,7 @@ def _decode_runlength(code, hi_level):
       pwr += 1
       yield from repeat(level, length)
 
-def load_jmara_grib2(file):
+def load_jmara_grib2(file, tar_flag=False, tar_contentname=None):
   r'''気象庁解析雨量やレーダー雨量を返す関数
 
   欠損値は負の値として表現される
@@ -40,19 +42,32 @@ def load_jmara_grib2(file):
   file: `str`
     file path 
     ファイルのPATH
+  tar_flag: `bool`
+    file type whether file is tar or GRIB2 (not tar).
+  tar_contentname: `str`
+    content name in tar file.
 
   Returns
   -------
   rain: `numpy.ma.MaskedArray`
-    単位 (mm)
+    Units(単位) [mm/h]
 
-  Notes
+  Note
   -----
   ``jma_rain_lat`` , ``jma_rain_lon`` はそれぞれ返り値に対応する
   `np.ndarray` 型の緯度経度である。
   '''
-  with open(file, 'rb') as f:
-    binary = f.read()
+  if tar_flag:
+    if tar_contentname == None:
+      raise NotHaveSetArgError("tar_flag", "tar_contentname")
+    with tarfile.open(file, mode="r") as tar:
+      for tarinfo in tar.getmembers():
+        if tarinfo.name == tar_contentname:
+          binary = b''.join(tar.extractfile(tarinfo).readlines())
+          break
+  else:
+    with open(file, 'rb') as f:
+      binary = f.read()
   
   len_ = {'sec0':16, 'sec1':21, 'sec3':72, 'sec4':82, 'sec6':6}
   
@@ -75,7 +90,7 @@ def load_jmara_grib2(file):
   # convert level to representative
   return np.ma.masked_less((level_table[decoded]/(10**power))[::-1, :], 0)
 
-def get_jrara_lat():
+def get_jmara_lat():
   r'''解析雨量の緯度を返す関数
 
   Returns
@@ -85,7 +100,7 @@ def get_jrara_lat():
   return np.linspace(48, 20, 3360, endpoint=False)[::-1] - 1/80/1.5 / 2
     
 
-def get_jrara_lon():
+def get_jmara_lon():
   r'''解析雨量の経度を返す関数
 
   Returns
@@ -143,4 +158,60 @@ jma_rain_lat = np.linspace(48, 20, 3360, endpoint=False)[::-1] - 1/80/1.5 / 2
 jma_rain_lon = np.linspace(118, 150, 2560, endpoint=False) + 1/80 / 2
 
 gsmap_lat = np.arange(-60, 60, 0.1)[::-1] + 0.05
-gsmap_lon = np.arange(0, 360, 0.1) + 0.05
\ No newline at end of file
+gsmap_lon = np.arange(0, 360, 0.1) + 0.05
+
+def unit_ms1_knots(ms):
+  r"""
+  Convert unit m/s into knots.
+  
+  Parameters
+  ----------
+  ms: `int`
+    Velocity in meter per second.
+  
+  Returns
+  -------
+  `kt`
+    Velocity in knots.
+  """
+  return ms*3600/1852
+
+def unit_knots_ms1(kt):
+  r"""
+  Convert unit knots into m/s.
+  
+  Parameters
+  ----------
+  kt: `int`
+    Velocity in knots.
+  
+  Returns
+  -------
+  `ms`
+    Velocity in meter per second.
+  """
+  return kt*1852/3600
+
+def anom_levels(levs):
+  """
+  Return minus ans plus levels.
+
+  Parameters
+  ----------
+  levs: `list`or`np.ndarray`
+
+  Returns
+  -------
+  anom levels: `np.ndarray`
+  
+  Examples  
+  --------
+      >>> levs = [0.5, 1., 2.]
+      >>> print(anom_levels(levs))
+      [-2.  -1.  -0.5  0.5  1.   2. ]
+  
+  
+  """
+  levs = list(set(np.abs(levs)))
+  levs.sort()
+  return np.array([-i for i in levs[::-1]]+levs)
\ No newline at end of file
